KG2E
====

.. currentmodule:: pykeen.models

.. autoclass:: KG2E
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~KG2E.hpo_default

   .. rubric:: Methods Summary

   .. autosummary::

      ~KG2E.expected_likelihood
      ~KG2E.kullback_leibler_similarity
      ~KG2E.post_parameter_update
      ~KG2E.score_h
      ~KG2E.score_hrt
      ~KG2E.score_t

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default

   .. rubric:: Methods Documentation

   .. automethod:: expected_likelihood
   .. automethod:: kullback_leibler_similarity
   .. automethod:: post_parameter_update
   .. automethod:: score_h
   .. automethod:: score_hrt
   .. automethod:: score_t
